@@ -1,3 +1,6 @@
+from datetime import datetime
+from dateutil import tz
+
 """Defines the Data Classes used."""
 
 class CurrentData:
@@ -7,6 +10,7 @@ class CurrentData:
         self._station = data["station"]
         self._city_name = data["city_name"]
         self._ob_time = data["ob_time"]
+        self._datetime = data["datetime"]
         self._temp = data["temp"]
         self._app_temp = data["app_temp"]
         self._humidity = data["rh"]
@@ -27,6 +31,8 @@ class CurrentData:
         self._uv = data["uv"]
         self._aqi = data["aqi"]
         self._timezone = data["timezone"]
+        self._sunrise = data["sunrise"]
+        self._sunset = data["sunset"]
 
     @property
     def station(self) -> str:
@@ -143,6 +149,43 @@ class CurrentData:
         """Local IANA Timezone."""
         return self._timezone
 
+    @property
+    def sunrise(self) -> str:
+        """Sunrise time (HH:MM)."""
+        return self._sunrise
+
+    @property
+    def sunset(self) -> str:
+        """Suntime time (HH:MM)."""
+        return self._sunset
+
+    @property
+    def datetime(self) -> str:
+        """Current cycle hour (YYYY-MM-DD:HH)."""
+        return self._datetime
+
+    @property
+    def is_night(self) -> bool:
+        """Returns True if night at location."""
+
+        from_zone = tz.gettz("UTC")
+        to_zone = tz.gettz(self.timezone)
+        obs_time = datetime.strptime(self.ob_time, "%Y-%m-%d %H:%M")
+        sun_rise = datetime.strptime(f"{obs_time.strftime('%Y-%m-%d')} {self.sunrise}", "%Y-%m-%d %H:%M")
+        sun_set = datetime.strptime(f"{obs_time.strftime('%Y-%m-%d')} {self.sunset}", "%Y-%m-%d %H:%M")
+
+        obs_day = obs_time.replace(tzinfo=from_zone)
+        sun_rise = sun_rise.replace(tzinfo=from_zone)
+        sun_set = sun_set.replace(tzinfo=from_zone)
+        obs_local = obs_day.astimezone(to_zone)
+        rise_local = sun_rise.astimezone(to_zone)
+        set_local = sun_set.astimezone(to_zone)
+
+        if obs_local >= set_local and obs_local <= rise_local:
+            return True
+        else:
+            return False
+
 class ForecastDailyData:
     """A representation of Daily Forecast Weather Data."""
 
